@@ -55,8 +55,9 @@ class Pool:
         if self.minsize > 0 or not self._free.empty():
             conn = yield from self._free.get()
         else:
-            conn = yield from connect(self._dsn, loop=self._loop,
-                                      **self._conn_kwargs)
+            conn = yield from connect(
+                self._dsn, loop=self._loop,
+                **self._conn_kwargs)
         assert not conn.closed, conn
         assert conn not in self._used, (conn, self._used)
         self._used.add(conn)
@@ -65,8 +66,9 @@ class Pool:
     @asyncio.coroutine
     def _fill_free_pool(self):
         while self.size < self.minsize:
-            conn = yield from connect(self._dsn, loop=self._loop,
-                                      **self._conn_kwargs)
+            conn = yield from connect(
+                self._dsn, loop=self._loop,
+                **self._conn_kwargs)
             yield from self._free.put(conn)
 
     def release(self, conn):
@@ -137,6 +139,8 @@ class _ConnectionContextManager:
             <block>
     """
 
+    __slots__ = ('_pool', '_conn')
+
     def __init__(self, pool, conn):
         self._pool = pool
         self._conn = conn
@@ -167,6 +171,8 @@ class _CursorContextManager:
             <block>
     """
 
+    __slots__ = ('_pool', '_conn', '_cur')
+
     def __init__(self, pool, conn, cur):
         self._pool = pool
         self._conn = conn
